=================
Welcome to radicl
=================


.. image:: https://img.shields.io/pypi/v/radicl.svg
        :target: https://pypi.python.org/pypi/radicl

.. image:: https://github.com/AdventureData/radicl/actions/workflows/build.yml/badge.svg
        :target: https://github.com/AdventureData/radicl/actions/workflows/build.yml


.. image:: https://readthedocs.org/projects/radicl/badge/?version=latest
        :target: https://radicl.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Command line interface to the Realtime Adventure Data's Lyte probe designed to
measure snow!

* Free software: BSD license
* Documentation: https://radicl.readthedocs.io.
* Source code: https://github.com/AdventureData/radicl
* Website: https://adventuredata.com/


Features
--------

* Command line interface to the Lyte probe (radicl)
* Take Measurements (lyte_hi_res)
* Change Probe Settings (radicl)
* Update the Probe Firmware
* Python API for interacting with the Lyte probe
* Commandline script for plotting profiles taken through the app (lyteplot, plot_hi_res)

